#
# spec file for package ghc-OpenGLRaw
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name OpenGLRaw
Name:           ghc-%{pkg_name}
Version:        3.2.5.0
Release:        lp150.1.8
Summary:        A raw binding for the OpenGL graphics system
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  Mesa-libGL-devel
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-fixed-devel
BuildRequires:  ghc-half-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel

%description
OpenGLRaw is a raw Haskell binding for the OpenGL 4.5 graphics system and lots
of OpenGL extensions. It is basically a 1:1 mapping of OpenGL's C API, intended
as a basis for a nicer interface. OpenGLRaw offers access to all necessary
functions, tokens and types plus a general facility for loading extension
entries. The module hierarchy closely mirrors the naming structure of the
OpenGL extensions, making it easy to find the right module to import.
All API entries are loaded dynamically, so no special C header files are needed
for building this package. If an API entry is not found at runtime, a userError
is thrown.

OpenGL is the industry's most widely used and supported 2D and 3D graphics
application programming interface (API), incorporating a broad set of
rendering, texture mapping, special effects, and other powerful visualization
functions. For more information about OpenGL and its various extensions, please
see <http://www.opengl.org/> and <http://www.opengl.org/registry/>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       Mesa-libGL-devel
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 3.2.5.0.
* Sun Dec  4 2016 psimons@suse.com
- Update to version 3.2.4.0 with cabal2obs.
* Tue Oct 11 2016 psimons@suse.com
- Update to version 3.2.3.0 with cabal2obs.
* Sun Aug 21 2016 psimons@suse.com
- Update to version 3.2.2.0 revision 0 with cabal2obs.
* Fri Jul 22 2016 psimons@suse.com
- Update to version 3.2.1.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 3.2.0.0 revision 0 with cabal2obs.
  This update obsoletes ghc-OpenGLRaw-rpmlintrc.
* Fri May 13 2016 mimi.vx@gmail.com
- update to 3.2.0.0
- removed useless _service
  * Updated OpenGL registry to r32749.
  * Updated warning flag magic for GHC 8.0.
* Mon Jan 11 2016 mimi.vx@gmail.com
- update to 3.1.0.0
  * Changed the type of GL_FALSE and GL_TRUE to GLboolean, leading to fewer
    fromIntegral calls in user code.
  * Added deprecated functions mkGLDEBUGPROC, mkGLDEBUGPROCAMD, mkGLDEBUGPROCARB,
    mkGLDEBUGPROCKHR for gl compatibility.
  * Updated OpenGL registry to r32348.
* Mon Jan  4 2016 mimi.vx@gmail.com
- update to 3.0.0.0
  * Make the OpenGLRaw package even more similar to the gl package:
    + Use pattern synonyms for OpenGL enums.
    + Changed module name prefix from Graphics.Rendering.OpenGL.Raw to Graphics.GL.
    + Use slightly different type synonyms for GL type (introducing Fixed on
    the way):
    . CDouble => Double (for GLclampd, GLdouble)
    . CFloat => Float (for GLclampf, GLfloat)
    . CInt => Fixed (for GLclampx, GLfixed)
    . CInt => Int32 (for GLint, GLsizei)
    . CSChar => Int8 (for GLbyte)
    . CShort => Int16 (for GLshort)
    . CUChar => Word8 (for GLboolean, GLubyte)
    . CUInt => Word32 (for GLbitfield, GLenum, GLhandleARB, GLuint)
    . CUShort => Word16 (for GLushort)
* Thu Dec 24 2015 mimi.vx@gmail.com
- update to 2.6.1.1
  * Relaxed upper version bound for transformers.
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 2.6.1.0
  * Updated OpenGL registry to r32258. Note that the major version was intentionally
  not bumped, because the signature change of glClearNamedFramebufferfi was a bug
  fix, see the corresponding issue on Khronos.
  * Added retrieval of version info and extensions.
  * Added extension predicates.
  * Added documentation for vector equivalents and aliases.
  * Consistently use UTF-8 as the encoding.
  * Added documentation for enumerant groups.
  * Added GL_EXT_multisampled_compatibility tokens and functions (gles2 extension only).
  * Added ARB_ES3_2_compatibility extension.
  * Added ARB_gpu_shader_int64 extension.
  * Added ARB_parallel_shader_compile extension.
  * Added ARB_sample_locations extension.
  * Added ARB_texture_filter_minmax extension.
  * Added INTEL_framebuffer_CMAA extension.
  * Added NV_conservative_raster_dilate extension.
* Sun Nov 15 2015 peter.trommler@ohm-hochschule.de
- update to 2.6.0.0
  * API enhancements
  * new dependency on ghc-half-devel
* Thu Aug  6 2015 mimi.vx@gmail.com
- update to 2.5.10
  * Moved foreign imports to own module.
  * Handle gles1 and gles2 APIs, too. Needs serious cleanup.
* Wed Apr 15 2015 mimi.vx@gmail.com
- add _constraints file ( 4G of mem )
* Tue Apr 14 2015 mimi.vx@gmail.com
- update to 2.4.1.0
  * no changelog
* Tue Sep  9 2014 peter.trommler@ohm-hochschule.de
- update to 1.5.0.0
  * no changelog
  * for Haskell Platform 2014.2.0.0
* Mon Sep  1 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file with cabal-rpm
* Fri Aug 22 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- more transparent packaging (fewer macros)
* Fri Mar 22 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag
* Thu Jan  3 2013 peter.trommler@ohm-hochschule.de
- update to 1.3.0.0 from upstream
- no changelog
* Sat May  5 2012 peter.trommler@ohm-hochschule.de
- spec file template generated by cabal2spec-0.25.5
- added copyright notice
* Mon Mar  5 2012 peter.trommler@ohm-hochschule.de
- Update to 1.2.0.0 from upstream
- Add BuildRoot tag for SLE_11
* Sat Dec 31 2011 peter.trommler@ohm-hochschule.de
- Added requires for Mesa
* Sat Dec 31 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
